#ifndef EXTENSIONS_WIICONTROLLER_ENTITYPLUGINS_WIICONTROLLED_H_3DOT
#define EXTENSIONS_WIICONTROLLER_ENTITYPLUGINS_WIICONTROLLED_H_3DOT
/*
// \file extensions/wiicontroller/entityplugins/wiicontrolled.h
//
// Description:
// An entity plugin that maps the orientation and position of the connected
// Wii-controller to selected entities in the scene.
//
// \Author Anders Sabinsky Tgern <ast@hoast.dk>
// \Author Lasse Jon Fuglsang Pedersen <fuglsang@diku.dk>
//
// \Copyright See COPYING file that comes with the 3DOT distribution
*/

#include <3DOT/extensions/wiicontroller/entityplugins/iwiicontrolled.h>
#include <entity/baseentityplugin.h>

namespace EXT_WIICONTROLLER_3DOT
{
	/*
	 * Class definition: WiiControlled
	 */

	class WiiControlled : public CORE_3DOT::BaseEntityPlugin<IWiiControlled>
	{
	public:

		WiiControlled(CORE_3DOT::HEntityPluginFactory factory);

	public:

		void OnAddedToEntity();
		void Serialize(CORE_3DOT::HSerializeStream stream);
		void Update();
	
	public:
		
		void SetWiiControlledOrientation(bool flag);
		bool GetWiiControlledOrientation() const;

		void SetWiiControlledPosition(bool flag);
		bool GetWiiControlledPosition() const;

		void OnOrientationChanged(CORE_3DOT::HRTTIUnknown sender,
								  CORE_3DOT::HRTTIUnknown data);
		void OnPositionChanged(CORE_3DOT::HRTTIUnknown sender,
							   CORE_3DOT::HRTTIUnknown data);
	
	private:

		bool mWiiControlledOrientation;
		bool mWiiControlledPosition;

		CORE_3DOT::HEventHandler mOrientationChangedHandler;
		CORE_3DOT::HEventHandler mPositionChangedHandler;

	};
}

#endif
