#ifndef EXTENSIONS_WIICONTROLLER_WIICONTROLLEREXTENSION_H_3DOT
#define EXTENSIONS_WIICONTROLLER_WIICONTROLLEREXTENSION_H_3DOT
/*
// \file extensions/wiicontroller/wiicontrollerextension.h
//
// Description:
// Connects to- and exposes data and events from a Wii-controller.
//
// \Author Anders Sabinsky Tgern <ast@hoast.dk>
// \Author Lasse Jon Fuglsang Pedersen <fuglsang@diku.dk>
//
// \Copyright See COPYING file that comes with the 3DOT distribution
*/

#include <3DOT/extensions/wiicontroller/iwiicontrollerextension.h>
#include <extension/baseextension.h>
#include <entity/event.h>
#include <WiiLib.h>

using namespace WiiLib;

namespace EXT_WIICONTROLLER_3DOT
{
	/*
	 * Class definition: WiiControllerExtension
	 */

	class WiiControllerExtension
		: public CORE_3DOT::BaseExtension<IWiiControllerExtension>
	{
	public:

		WiiControllerExtension(APPLICATION_3DOT::HApplication app);
		~WiiControllerExtension();

	public:

		virtual void		Initialize(APPLICATION_3DOT::HApplication app,
									   EDITOR_3DOT::HEditor editor);

	public:

		void				Process();

		CORE_3DOT::quat		GetOrientation() const;
		CORE_3DOT::vec3		GetPosition() const;

		CORE_3DOT::HEvent	GetButtonStatesChangedEvent();
		CORE_3DOT::HEvent	GetOrientationChangedEvent();
		CORE_3DOT::HEvent	GetPositionChangedEvent();

	private:

		Controller			mController;		// WiiLib controller class
		Tilt				mEstTilt;			// WiiLib tilt estimator
		Position			mEstPosition;		// WiiLib position estimator

		int					mButtonStates;		// last known button data
		CORE_3DOT::quat		mOrientation;		// last known orientation
		CORE_3DOT::vec3		mPosition;			// last known position

		CORE_3DOT::HEvent	mButtonStatesChangedEvent;
		CORE_3DOT::HEvent	mOrientationChangedEvent;
		CORE_3DOT::HEvent	mPositionChangedEvent;

	private:

		bool				WiiControllerExtension::ConnectAndCalibrate();
		CORE_3DOT::vec3		WiiControllerExtension::ConvWiiLibVec3(Vec3 &v);

	};
}

#endif
